# $Id: php-modules.spec 16 2005-12-13 10:32:25Z matthias $

%define php_extdir %(php-config --extension-dir 2>/dev/null || echo %{_libdir}/php4)
%{!?php_version:%define php_version %(php-config --version 2>/dev/null || echo 4.4.1)}
%define oracle_version %(oracle-instantclient-config --version 2>/dev/null || echo 10.2.0.2)
%define extensions mcrypt oci8

Summary: Additional PHP extension modules
Name: php-modules
Version: %{php_version}
Release: 3.el4
License: PHP
Group: Development/Languages
URL: http://www.php.net/
Source: http://www.php.net/distributions/php-%{version}.tar.bz2
Patch0: php-4.3.9-oci8.patch
#Patch1: php-4.3.11-pdf-lib64.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: php, php-devel = %{php_version}
# Required by phpize
BuildRequires: autoconf, automake, libtool, gcc-c++

%description
PHP is an HTML-embedded scripting language. PHP attempts to make it
easy for developers to write dynamically generated webpages. PHP also
offers built-in database integration for several commercial and
non-commercial database management systems, so writing a
database-enabled webpage with PHP is fairly simple. The most common
use of PHP coding is probably as a replacement for CGI scripts. The
mod_php module enables the Apache Web server to understand and process
the embedded PHP language in Web pages.

This package rebuilds many additional extension modules.


%package -n php-mcrypt
Summary: A module for PHP applications that use encryption routines.
Group: Development/Languages
#Requires: php = %{version}
Requires: php >= 4.3.9
BuildRequires: libmcrypt-devel
Provides: php_encryption

%description -n php-mcrypt
The php-mcrypt package contains a dynamic shared object that will add
support for using encryption routines with PHP.


%package -n php-oci8
Summary: An OCI8 (Oracle) database module for PHP.
Group: Development/Languages
#Requires: php = %{version}, oracle-instantclient-basic
Requires: php >= 4.3.9, oracle-instantclient-basic
BuildRequires: oracle-instantclient-devel
Provides: php_database

%description -n php-oci8
The php-oci8 package includes a dynamic shared object (DSO) that can
be compiled in to the Apache Web server to add Oracle 8i/9i database
support to PHP.


#%package -n php-mime_magic
#Summary: A PHP module to guess the content type and encoding of a file.
#Group: Development/Languages
#Requires: php = %{version}, file
#
#%description -n php-mime_magic
#The functions in this module try to guess the content type and encoding of a
#file by looking for certain magic byte sequences at specific positions within
#the file. While this is not a bullet proof approach the heuristics used do a
#very good job.
#This extension is derived from Apache mod_mime_magic, which is itself based
#on the file command maintained by Ian F. Darwin.


#%package -n php-pdf
#Summary: A PHP module to generate PDF files using pdflib
#Group: Development/Languages
#Requires: php = %{version}
#BuildRequires: pdflib-devel, gd-devel
#BuildRequires: zlib-devel, libjpeg-devel, libpng-devel, libtiff-devel
#
#%description -n php-pdf
#The php-pdf package contains a dynamic shared object that will add support
#for generating PDF files by using pdflib.


#%package -n php-xslt
#Summary: A PHP module for Extensible Stylesheet Language Transformations
#Group: Development/Languages
#Requires: php = %{version}, sablotron
#BuildRequires: sablotron-devel, expat-devel, glibc-headers, glibc-devel
##libiconv-devel
#
#%description -n php-xslt
#This module contains a processor independent API for XSLT, the Extensible
#Stylesheet Language Transformations, which uses Sablotron as the backend.


%prep 
%setup -q -n php-%{version}
%patch0 -p1 -b .oci8
#ifarch x86_64
#patch1 -p1 -b .pdf-lib64
#endif


%build
unset ORACLE_HOME
for ext in %{extensions}; do
    if [ "${ext}" = "xslt" ]; then
        options="--with-xslt-sablot --with-sablot-js"
#    elif [ "${ext}" = "pdf" ]; then
#        # Ugly include workaround
#        mkdir ext/pdf/ext
#        ln -s ../../gd ext/pdf/ext/gd
#        options="--with-jpeg-dir=%{_prefix} --with-png-dir=%{_prefix} --with-zlib-dir=%{_prefix} --with-tiff-dir=%{_prefix}"
    elif [ "${ext}" = "oci8" ]; then
        options="--with-oci8-instant-client=%{_libdir}/oracle/%{oracle_version}/client/%{_lib}"
    else
        options=""
    fi
    pushd ext/${ext}
        phpize
        %configure ${options}
        %{__make}
    popd
done


%install
%{__rm} -rf %{buildroot}
for ext in %{extensions}; do
    pushd ext/${ext}
        %{__make} install INSTALL_ROOT=%{buildroot}
    popd
done

# Drop in the bits of configuration
%{__mkdir_p} %{buildroot}%{_sysconfdir}/php.d
for ext in %{extensions}; do
    %{__cat} > %{buildroot}%{_sysconfdir}/php.d/${ext}.ini << EOF
; Enable ${ext} extension module
extension=${ext}.so
EOF
done

# Specific configuration additions

# mime_magic
#%{__cat} >> %{buildroot}%{_sysconfdir}/php.d/mime_magic.ini << EOF
#
#; Configuration
#mime_magic.magicfile = /usr/share/file/magic.mime
#EOF


%clean
%{__rm} -rf %{buildroot}


%files -n php-mcrypt
%defattr(-, root, root, 0755)
%doc ext/mcrypt/CREDITS ext/mcrypt/TODO
%config(noreplace) %{_sysconfdir}/php.d/mcrypt.ini
%{php_extdir}/mcrypt.so

%files -n php-oci8
%defattr(-, root, root, 0755)
%doc ext/oci8/CREDITS
%config(noreplace) %{_sysconfdir}/php.d/oci8.ini
%{php_extdir}/oci8.so

#%files -n php-mime_magic
#%defattr(-, root, root, 0755)
#%doc ext/mime_magic/CREDITS ext/mime_magic/TODO
#%config(noreplace) %{_sysconfdir}/php.d/mime_magic.ini
#%{php_extdir}/mime_magic.so

#%files -n php-pdf
#%defattr(-, root, root, 0755)
#%doc ext/pdf/CREDITS
#%config(noreplace) %{_sysconfdir}/php.d/pdf.ini
#%{php_extdir}/pdf.so

#%files -n php-xslt
#%defattr(-, root, root, 0755)
#%doc ext/xslt/README.XSLT-BACKENDS ext/xslt/TODO
#%config(noreplace) %{_sysconfdir}/php.d/xslt.ini
#%{php_extdir}/xslt.so


%changelog
* Mon Apr 24 2006 Matthias Saou <http://freshrpms.net/> 4.3.9-3
- Switch to using oracle-instantclient-config to get the Oracle version.
- Fix oci8 instant client patch to work on x86_64 too.
- Rebuild vanilla RHEL4 4.3.9-3 oci8 module.

* Tue Jul 19 2005 Matthias Saou <http://freshrpms.net/> 4.4.0-1
- Update to 4.4.0.
- Remove pdf module, we now use php-pecl-pdflib instead (much more recent).
- Remove mime_magic module, it's now built into PHP.

* Tue Apr 12 2005 Matthias Saou <http://freshrpms.net/> 4.3.11-1
- Update to 4.3.11, remove no longer needed oci8 instant client patch.
- Actually, plain oci8 doesn't want to be disabled... so patch again to remove.
- Add php-4.3.11-pdf-lib64.patch (for x86_64 only, as it changes all "lib"s).

* Wed Feb  9 2005 Matthias Saou <http://freshrpms.net/> 4.3.10-1
- Added php-pdf module.

* Mon Jan 17 2005 Matthias Saou <http://freshrpms.net/> 4.3.10-1
- Rebuild 4.3.10 modules for FC2 errata.

* Thu Sep  2 2004 Matthias Saou <http://freshrpms.net/> 4.3.8-2
- Rebuilt with Oracle 9i libs (vs. 8i previously).
- Remove dba module, it's built in the main, so not overridable.

* Tue Jun 29 2004 Matthias Saou <http://freshrpms.net/> 4.3.6-1
- Added dba module.

* Tue May 18 2004 Matthias Saou <http://freshrpms.net/> 4.3.6-1
- Rebuilt for 4.3.6.

* Thu May 13 2004 Matthias Saou <http://freshrpms.net/> 4.3.4-1
- Added mime_magic module.

* Fri May  7 2004 Matthias Saou <http://freshrpms.net/> 4.3.4-1
- Initial RPM release.

